==> safecheck-3.0.4-15.jar: safecheck/sqls/FetchUserFileByOrgNoRuHuSXQ.sql <==
select * from(select
	ui.f_userinfo_id,
	f_userinfo_code,
	ua.f_area,
	ua.f_street,
	ua.f_building,
	ua.f_unit,
	ua.f_residential_area,
	ua.f_floor,
	ua.f_room,
	ua.f_address,
-- 	f_user_family_remarks,
--		de.f_devices_type,
	{
	month != $$ :
	$
	1 code,
	$,
	$$
	}
	f_user_name,
	f_user_phone,
	ua.f_last_check_state,
	ua.f_last_check_date,
	ua.f_last_check_result,
  ui.f_comments,
	ui.version,
	ua.id,
	f_plan_name,
	uf.f_user_type,
	ui.f_check_area, --片区编号
	ca.f_area_name -- 片区名称
--	ui.f_filiale
 from
		t_userinfo ui
		left join t_check_area ca on ca.id = ui.f_check_area
    left join t_user_address ua on ui.f_userinfo_id = ua.f_userinfo_id
    left join t_userfiles uf on uf.f_userinfo_id=ui.f_userinfo_id
    left join t_check_plan cp on ua.f_plan_id = cp.id
	--	left join t_devices de on ui.f_userinfo_id =de.f_userinfo_id
where {condition} and (uf.f_table_state='正常' or uf.f_table_state='停用')
{
		f_usertype != $$:
		$
		And uf.f_user_type = '{f_usertype}' $,
		$$
}
{
	month != $$ :
	$
	and  datediff(month,ua.f_last_check_date, getdate())>={month}
	$,
	month == $$ :
	$
  and	1=1
	$,
	$$
}
{
	SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $$ :
  $
	and  ( isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
	$,
  SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $是$ :
  $
  and  ( isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and  ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) <= GETDATE())
  $,
  SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $否$ :
  $
  and  ( isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) >= GETDATE())
  $,
	SafeCheckSX.f_check_start == $$ && SafeCheckSX.f_check_end != $$:
	$
  and	 (isnull(ua.f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null)
	$,
		SafeCheckSX.f_check_start != $$ && SafeCheckSX.f_check_end == $$:
	$
  and	 (isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) is null)
	$,
	$$
}
) a
order by {orderitem}

==> safecheck-3.0.8.jar: safecheck/sqls/FetchUserFileByOrgNoRuHuSXQ.sql <==
select * from(select
	ui.f_userinfo_id,
	f_userinfo_code,
	ua.f_street,
	ua.f_building,
	ua.f_unit,
	ua.f_residential_area,
	ua.f_floor,
	ua.f_room,
	ua.f_address,
-- 	f_user_family_remarks,
--		de.f_devices_type,
	{
	month != $$ :
	$
	1 code,
	$,
	$$
	}
	f_user_name,
	f_user_phone,
	ua.f_last_check_state,
	ua.f_last_check_date,
	ua.f_last_check_result,
  ui.f_comments,
	ui.version,
	ua.id,
	f_plan_name,
	uf.f_user_type,
	uf.f_metertitles,
	mb.f_book_slice_area,
	mb.f_book_name
--	ui.f_filiale
 from
		t_userinfo ui
    left join t_user_address ua on ui.f_userinfo_id = ua.f_userinfo_id
    left join t_userfiles uf on uf.f_userinfo_id=ui.f_userinfo_id
    left join t_meter_book mb on mb.id=uf.f_meter_book_num
    left join t_check_plan cp on ua.f_plan_id = cp.id
    left join t_userproperties up on ui.f_userinfo_id=up.f_userinfo_id and up.f_state='有效' and up.f_parameter_key='blackList'

	--	left join t_devices de on ui.f_userinfo_id =de.f_userinfo_id
where {condition} and (uf.f_table_state='正常' or uf.f_table_state='停用')
{
		f_usertype != $$:
		$
		And uf.f_user_type = '{f_usertype}' $,
		$$
}
{
	month != $$ :
	$
	and  datediff(month,ua.f_last_check_date, getdate())>={month}
	$,
	month == $$ :
	$
  and	1=1
	$,
	$$
}
{
	SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $$ :
  $
	and  ( isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
	$,
  SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $是$ :
  $
  and  ( isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and  ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) <= GETDATE())
  $,
  SafeCheckSX.f_check_start != $$ &&  SafeCheckSX.f_check_end != $$ && SafeCheckCQ == $否$ :
  $
  and  ( isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null )
  and ( DATEADD(month,{safeCycle},isnull(f_last_check_date,f_createfile_date)) >= GETDATE())
  $,
	SafeCheckSX.f_check_start == $$ && SafeCheckSX.f_check_end != $$:
	$
  and	 (isnull(ua.f_last_check_date,f_createfile_date) >= '{SafeCheckSX.f_check_end}' or isnull(f_last_check_date,f_createfile_date) is null)
	$,
		SafeCheckSX.f_check_start != $$ && SafeCheckSX.f_check_end == $$:
	$
  and	 (isnull(ua.f_last_check_date,f_createfile_date) <= '{SafeCheckSX.f_check_start}' or isnull(f_last_check_date,f_createfile_date) is null)
	$,
	$$
}
) a
order by {orderitem}
